local Snoop_Help = {
    "Snoop usage:",
    "/snoop N  -- Sets output to go to chat window N, where N is from 1 to "..NUM_CHAT_WINDOWS,
    "/snoop print -- Prints each chat window's number in that window for reference.",
    "/snoop on|off -- Begins|ends copying addon channel text to the selected chat window.",
    "/snoop esc -- Toggles the formatting of control chars into escape sequences (default on)",
    "/snoop pipe -- Toggles the formatting of raw '|' chars into visible '|' (default off)",
}
--[[
Farmbuyer, Kilrogg realm
farmbuyer@gmail.com
]]

Snoop_ChatFrame = 2

local function printhelp()
    for _,v in ipairs(Snoop_Help) do
        DEFAULT_CHAT_FRAME:AddMessage (v,1,1,1)
    end
    DEFAULT_CHAT_FRAME:AddMessage ("Snoop is set to print to chat window "..Snoop_ChatFrame..".")
end


local green = "|cFF00FF00"
local open = green.."<"
local close = green..">"
local openprefix = open.."|cFFFF0088"
local ppl = "|cFFFEC500"
local escape_control = true
local escape_pipe = false

local f
local function repl (c)
    return ([[\%.3d]]):format(c:byte())
end
local function Snoop_OnEvent (self, event, prefix, msg, dist, sender)
    if escape_control then
        msg = msg:gsub("%c",repl)
    end
    if escape_pipe then
        msg = msg:gsub('\124','\124\124')
    end
    f:AddMessage(("%s%s%s%s(%s->%s):  |r%s"):
                  format(openprefix, prefix, close, ppl, sender, dist, msg),
                 0.41, 0.8, 0.94)
end

local SnoopFrame = CreateFrame("Frame")
SnoopFrame:SetScript("OnEvent", Snoop_OnEvent)

SlashCmdList["SNOOP"] = function (txt)
	txt = strtrim(txt:lower())
	if txt == "print" then
		for i = 1, NUM_CHAT_WINDOWS do
			local frm = _G["ChatFrame"..i]
			if frm then
				frm:AddMessage ("This is chat window "..i..".",1,1,1)
			end
		end
	elseif txt == "on" then
		DEFAULT_CHAT_FRAME:AddMessage ("Snoop activated.")
		Snoop_ChatFrame = Snoop_ChatFrame or 2
		f = _G["ChatFrame"..Snoop_ChatFrame]
		SnoopFrame:RegisterEvent("CHAT_MSG_ADDON")
	elseif txt == "off" then
		DEFAULT_CHAT_FRAME:AddMessage ("Snoop deactivated.")
		f = nil
		SnoopFrame:UnregisterEvent("CHAT_MSG_ADDON")
	elseif txt == "esc" then
		escape_control = not escape_control
		DEFAULT_CHAT_FRAME:AddMessage ("Snoop control character escaping now "
			..(escape_control and "on" or "off"))
	elseif txt == "pipe" then
		escape_pipe = not escape_pipe
		DEFAULT_CHAT_FRAME:AddMessage ("Snoop pipe character escaping now "
			..(escape_pipe and "on" or "off"))
	else
		-- "/snoop N"
		local n = tonumber (txt or "")
		if (not n) or (n < 1) or (n > NUM_CHAT_WINDOWS) then
			-- if they type something like "/snoop 3.141" then screw 'em
			printhelp()
		else
			Snoop_ChatFrame = n
			f = _G["ChatFrame"..Snoop_ChatFrame]
			DEFAULT_CHAT_FRAME:AddMessage ("Snoop will now print to chat window "..n..".")
		end
	end
end
SLASH_SNOOP1 = "/snoop"

-- vim: noet
